# A single sprite

import pyglet

BOUNDS = (50, 50, 500, 400)

class MySprite(pyglet.sprite.Sprite):

    def __init__(self, img, x, y, x_velocity, y_velocity, batch, group):
        super(MySprite, self).__init__(img, x, y, batch=batch,
                group=group)
        self.x_velocity = x_velocity
        self.y_velocity = y_velocity
        pyglet.clock.schedule_interval(self.update, 0.016)

    def _check_x_bounds(self):
       if self.x < BOUNDS[0] or self.x > BOUNDS[2]:
          return False
       return True

    def _check_y_bounds(self):
       if self.y < BOUNDS[1] or self.y > BOUNDS[3]:
          return False
       return True

    def update(self, dt):
       self.x += self.x_velocity
       self.y += self.y_velocity
       if not self._check_x_bounds():
          self.x_velocity = -self.x_velocity
       if not self._check_y_bounds():
          self.y_velocity = -self.y_velocity

class MyWindow(pyglet.window.Window):

    def __init__(self):
        super(MyWindow, self).__init__()
        self._image1 = pyglet.resource.image('blueball.png')
        self._image2 = pyglet.resource.image('redball.png')
        self.batch = pyglet.graphics.Batch()
        self.background = pyglet.graphics.OrderedGroup(0)
        self.middle = pyglet.graphics.OrderedGroup(1)
        self.foreground = pyglet.graphics.OrderedGroup(2)
        for index in range(10):
            if index < 4:
                group = self.background
            elif index < 8:
                group = self.middle
            else:
                group = self.foreground
            if index % 2:
                sprite = MySprite(self._image1, 200 + index, 200 - index,
                        index, 3, self.batch, group)
            else:
                sprite = MySprite(self._image2, 200 + index, 200 - index,
                        3, -index, self.batch, group)

    def on_draw(self):
        self.clear()
        self.batch.draw()

if __name__ == "__main__":
    win = MyWindow()
    pyglet.app.run()
